ScreenSecurityPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- ScreenSecurityPlatform
- Implementers
Constructors
- ScreenSecurityPlatform()
- Constructs a ScreenSecurityPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableScreenSecurity(
) → Future< void> - Disables screen security, allowing screenshots and screen recording.
-
enableScreenSecurity(
) → Future< void> - Enables screen security to prevent screenshots and screen recording.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ ScreenSecurityPlatform
-
The default instance of ScreenSecurityPlatform to use.
getter/setter pair