enableScreenSecurity method
Enables screen security to prevent screenshots and screen recording.
Implementation
Future<void> enableScreenSecurity() {
throw UnimplementedError('enableScreenSecurity() has not been implemented.');
}
Enables screen security to prevent screenshots and screen recording.
Future<void> enableScreenSecurity() {
throw UnimplementedError('enableScreenSecurity() has not been implemented.');
}